#!/usr/bin/env python

if __name__ == '__main__':
    from airtest import console
    console.main()
